==> integreat-cms-2023.10.1.tar.gz: integreat-cms-2023.10.1/integreat_cms/core/signals/hix_signals.py <==
import logging

from django.db.models.signals import pre_save
from django.dispatch import receiver

from ...cms.models import PageTranslation
from ...cms.views.utils.hix import lookup_hix_score

logger = logging.getLogger(__name__)


@receiver(pre_save, sender=PageTranslation)
def page_translation_save_handler(instance, **kwargs):
    r"""
    Calculates a hix store for a page translation before saving

    :param instance: The page translation that gets saved
    :type instance: ~integreat_cms.cms.models.pages.page_translation.PageTranslation

    :param \**kwargs: The supplied keyword arguments
    :type \**kwargs: dict
    """

    if kwargs.get("raw"):
        return

    if instance.hix_ignore or not instance.hix_enabled or not instance.content.strip():
        logger.debug(
            "HIX calculation pre save signal skipped for %r (ignored=%s, enabled=%s, empty=%s)",
            instance,
            instance.hix_ignore,
            instance.hix_enabled,
            not bool(instance.content.strip()),
        )
        instance.hix_score = None
        return

    latest_version = instance.latest_version

    if (
        latest_version
        and latest_version.hix_score
        and latest_version.content == instance.content
    ):
        logger.debug(
            "Content of %r was not changed, copying the HIX score from the previous version: %r",
            instance,
            latest_version.hix_score,
        )
        instance.hix_score = latest_version.hix_score
        return

    if score := lookup_hix_score(instance.content):
        logger.debug("Storing hix score %s for %r", score, instance)
        instance.hix_score = score
    else:
        logger.warning("Could not store the hix score for %r", instance)

==> integreat-cms-2024.2.0.tar.gz: integreat-cms-2024.2.0/integreat_cms/core/signals/hix_signals.py <==
from __future__ import annotations

import logging
from typing import TYPE_CHECKING

from django.db.models.signals import pre_save
from django.dispatch import receiver

if TYPE_CHECKING:
    from typing import Any
    from integreat_cms.cms.models.pages.page_translation import PageTranslation

from ...cms.models import PageTranslation
from ...cms.views.utils.hix import lookup_hix_score

logger = logging.getLogger(__name__)


@receiver(pre_save, sender=PageTranslation)
def page_translation_save_handler(instance: PageTranslation, **kwargs: Any) -> None:
    r"""
    Calculates a hix store for a page translation before saving

    :param instance: The page translation that gets saved
    :param \**kwargs: The supplied keyword arguments
    """

    if kwargs.get("raw"):
        return

    if instance.hix_ignore or not instance.hix_enabled or not instance.content.strip():
        logger.debug(
            "HIX calculation pre save signal skipped for %r (ignored=%s, enabled=%s, empty=%s)",
            instance,
            instance.hix_ignore,
            instance.hix_enabled,
            not bool(instance.content.strip()),
        )
        instance.hix_score = None
        return

    latest_version = instance.latest_version

    if (
        latest_version
        and latest_version.hix_score
        and latest_version.content == instance.content
    ):
        logger.debug(
            "Content of %r was not changed, copying the HIX score from the previous version: %r",
            instance,
            latest_version.hix_score,
        )
        instance.hix_score = latest_version.hix_score
        return

    if score := lookup_hix_score(instance.content):
        logger.debug("Storing hix score %s for %r", score, instance)
        instance.hix_score = score
    else:
        logger.warning("Could not store the hix score for %r", instance)
